@@ -32,6 +32,9 @@ class TimeModel(GObject.GObject):
         self.gain = gain
         self.secs = secs
 
+        # in FICS games we don't count gain
+        self.handle_gain = True
+
         self.paused = False
         # The left number of secconds at the time pause was turned on
         self.pauseInterval = 0
@@ -103,17 +106,16 @@ class TimeModel(GObject.GObject):
         if self.paused:
             return
 
+        gain = self.gain if self.handle_gain else 0
+        ticker = self.intervals[self.movingColor][-1] + gain
         if self.started:
-            ticker = self.intervals[self.movingColor][-1] + self.gain
             if self.counter is not None:
                 ticker -= time() - self.counter
-            self.intervals[self.movingColor].append(ticker)
         else:
-            self.intervals[self.movingColor].append(self.intervals[
-                self.movingColor][-1] + self.gain)
             # FICS rule
-            if self.ply >= 2:
+            if self.ply >= 1:
                 self.started = True
+        self.intervals[self.movingColor].append(ticker)
 
         self.movingColor = 1 - self.movingColor
 
@@ -126,7 +128,6 @@ class TimeModel(GObject.GObject):
     def start(self):
         if self.started:
             return
-        self.started = True
         self.counter = time()
         self.emit("time_changed")
 
@@ -198,9 +199,9 @@ class TimeModel(GObject.GObject):
     ############################################################################
 
     def updatePlayer(self, color, secs):
+        self.intervals[color][-1] = secs
         if color == self.movingColor and self.started:
             self.counter = secs + time() - self.intervals[color][-1]
-        self.intervals[color][-1] = secs
         self.emit("time_changed")
 
     ############################################################################
