@@ -855,11 +855,11 @@ class ChatWindow(object):
 
         uistuff.keepWindowSize("chat", self.window, defaultSize=(650, 400))
 
-        dock = PyDockTop("icchat")
-        dock.show()
-        self.window.add(dock)
+        self.dock = PyDockTop("icchat")
+        self.dock.show()
+        self.window.add(self.dock)
 
-        leaf = dock.dock(self.viewspanel,
+        leaf = self.dock.dock(self.viewspanel,
                          CENTER,
                          Gtk.Label(label="chat"),
                          "chat")
@@ -906,9 +906,11 @@ class ChatWindow(object):
     def onPersonMessage(self, cm, name, title, isadmin, text):
         console_active = False
         for window in Gtk.Window.list_toplevels():
-            if window.is_active() and "pychess" in window.get_icon_name():
-                console_active = True
-                break
+            if window.is_active():
+                window_icon_name = window.get_icon_name()
+                if window_icon_name is not None and "pychess" in window_icon_name:
+                    console_active = True
+                    break
 
         if self.connection.bm.isPlaying() or console_active:
             if not self.window:
